#include <cutter.h>

void test_do_nothing (void);

void
cut_setup (void)
{
    cut_error("Error in cut_setup()");
}

void
test_do_nothing (void)
{
}

/*
vi:ts=4:nowrap:ai:expandtab:sw=4
*/
